``aiomisc_log`` module
======================

``aiomisc_log.formatter.color`` module
++++++++++++++++++++++++++++++++++++++

.. automodule:: aiomisc_log.formatter.color
    :members:
    :undoc-members:
    :show-inheritance:

``aiomisc_log.formatter.journald`` module
+++++++++++++++++++++++++++++++++++++++++

.. automodule:: aiomisc_log.formatter.journald
    :members:
    :undoc-members:
    :show-inheritance:

``aiomisc_log.formatter.json`` module
++++++++++++++++++++++++++++++++++++++

.. automodule:: aiomisc_log.formatter.json
    :members:
    :undoc-members:
    :show-inheritance:

``aiomisc_log.formatter.rich.py`` module
++++++++++++++++++++++++++++++++++++++++


.. automodule:: aiomisc_log.formatter.rich
    :members:
    :undoc-members:
    :show-inheritance:

``aiomisc_log.enum`` module
+++++++++++++++++++++++++++

.. automodule:: aiomisc_log.enum
    :members:
    :undoc-members:
    :show-inheritance:
